@@ -1,6 +1,6 @@
 """ Login related functions """
 
-from flask import abort, flash
+from flask import abort, flash, g
 from flask_login import LoginManager, current_user, login_required, login_user, logout_user
 
 from textflow import service
@@ -10,7 +10,6 @@ __all__ = [
     'login_user',
     'login_required',
     'roles_required',
-    'current_user',
     'logout_user',
 ]
 
@@ -24,6 +23,11 @@ def roles_required(role):
     :return: decorated function
     """
 
+    if not isinstance(role, set):
+        if isinstance(role, str):
+            role = [role]
+        role = set(role)
+
     def default(func):
         def decorated_func(*args, **kwargs):
             user_id = current_user.id
@@ -37,7 +41,8 @@ def roles_required(role):
             if assignment is None:
                 flash('Invalid user or project identity', 'error')
                 abort(401)
-            elif assignment.role == role:
+            elif assignment.role in role:
+                g.current_user_role = assignment.role
                 return func(*args, **kwargs)
             else:
                 flash('You are not authorize to access the resource', 'error')
