@@ -5,7 +5,16 @@ from sqlalchemy.exc import SQLAlchemyError
 
 from textflow.model import *
 from textflow.service.base import service, database as db
-from textflow.utils import Dictionary as Map
+
+
+@service
+def list_users(ctx):
+    """Loads user from ID
+
+    :param ctx: context
+    :return: user if exist
+    """
+    return User.query.all()
 
 
 @service
@@ -200,6 +209,17 @@ def get_annotation_set(ctx, user_id, project_id, document_id):
     return annotation_set
 
 
+@service
+def get_label(ctx, label_id):
+    """Loads user from ID
+
+    :param ctx: context
+    :param label_id: label id
+    :return: user if exist
+    """
+    return Label.query.get(int(label_id))
+
+
 @service
 def filter_label(ctx, project_id, value):
     """Gets label from value [unique for project]
@@ -209,7 +229,34 @@ def filter_label(ctx, project_id, value):
     :param value: value
     :return: label
     """
-    return Label.query.filter_by(project_id=project_id, value=value).one()
+    return Label.query.filter_by(project_id=project_id, value=value).first()
+
+
+@service
+def list_labels(ctx, project_id, user_id):
+    """List all labels
+
+    :param ctx: context
+    :param project_id: project id
+    :return: label
+    """
+    return Label.query.filter_by(project_id=project_id).all()
+
+
+@service
+def delete_label(ctx, label_id):
+    """Delete label
+
+    :param ctx:
+    :param label_id:
+    :return:
+    """
+    obj = get_label(label_id)
+    if obj is None:
+        return False
+    db.session.delete(obj)
+    db.session.commit()
+    return True
 
 
 @service
@@ -263,9 +310,12 @@ def list_projects(ctx, user_id, paginate=None, paginate_kwargs=None):
     :param paginate_kwargs: paginate keyword args
     :return: get user
     """
-    q = Project.query \
-        .join(Assignment, Assignment.project_id == Project.id) \
-        .filter(Assignment.user_id == user_id)
+    if ctx.ignore_user:
+        q = Project.query
+    else:
+        q = Project.query \
+            .join(Assignment, Assignment.project_id == Project.id) \
+            .filter(Assignment.user_id == user_id)
     if paginate is not None:
         return q.paginate(**paginate_kwargs)
     return q.all()
@@ -371,13 +421,24 @@ def generate_status_report(ctx, user_id, project_id=None):
             progress = 100
         else:
             progress = num_completed * 100 / num_assigned
-        return Map(
-            num_annotations=Map({v: (l, c) for v, l, c in num_annotations}),
+        return dict(
+            num_annotations={v: (l, c) for v, l, c in num_annotations},
             num_assigned=num_assigned,
             num_completed=num_completed,
             progress=progress,
         )
-    return Map()
+    return {}
+
+
+@service
+def list_assignments(ctx, project_id):
+    """Gets assignment using provided user and project id.
+
+    :param ctx: context
+    :param project_id: project id
+    :return: Assigment if exist else None
+    """
+    return Assignment.query.filter(Assignment.project_id == project_id).all()
 
 
 @service
